/* svm_struct_latent_api_types.h */
/* 30 September 2008 */

# include "svm_light/svm_common.h"

typedef struct pattern {
  /*
    Type definition for input pattern x
  */
  int length;
  char *sequence;
  int example_id;
  char seq_name[1000];
  int example_type; /* example type (background or not?) for cost */
  double example_cost;
} PATTERN;

typedef struct label {
  /*
    Type definition for output label y
  */
  int label; /* +1 or -1 */
} LABEL;

typedef struct latent_var {
  /*
    Type definition for latent variable h
  */
  int position; /* position of motif */
} LATENT_VAR;

typedef struct example {
  PATTERN x;
  LABEL y;
  LATENT_VAR h;
} EXAMPLE;

typedef struct sample {
  int n;
  EXAMPLE *examples;
} SAMPLE;


typedef struct structmodel {
  double *w;          /* pointer to the learned weights */
  MODEL  *svm_model;  /* the learned SVM model */
  long   sizePsi;     /* maximum number of weights in w */
  /* other information that is needed for the stuctural model can be
     added here, e.g. the grammar rules for NLP parsing */
  int **pattern_hash; /* hash encodings for substrings */
  long n;             /* number of examples */
} STRUCTMODEL;


typedef struct struct_learn_parm {
  double epsilon;              /* precision for which to solve
				  quadratic program */
  long newconstretrain;        /* number of new constraints to
				  accumulate before recomputing the QP
				  solution */
  double C;                    /* trade-off between margin and loss */
  char   custom_argv[20][1000]; /* string set with the -u command line option */
  int    custom_argc;          /* number of -u command line options */
  int    slack_norm;           /* norm to use in objective function
                                  for slack variables; 1 -> L1-norm, 
				  2 -> L2-norm */
  int    loss_type;            /* selected loss function from -r
				  command line option. Select between
				  slack rescaling (1) and margin
				  rescaling (2) */
  int    loss_function;        /* select between different loss
				  functions via -l command line
				  option */
  /* add your own variables */
  int bg_markov_order;
  int motif_length;
  double false_negative_cost; 
} STRUCT_LEARN_PARM;

